Envelope codec: one durable Fressian file = header map + item stream.
Layout (in stream order): header, item-count, items. Handlers resolve through hive-fressian.registry at call time, so any domain registered before the call serializes transparently.
Envelope codec: one durable Fressian file = header map + item stream. Layout (in stream order): header, item-count, items. Handlers resolve through hive-fressian.registry at call time, so any domain registered before the call serializes transparently.
(read-envelope path)Read an envelope from path. Returns {:header map :items [..]}.
Read an envelope from `path`. Returns {:header map :items [..]}.
(write-envelope! path header items)Write items (seqable) under header (map) to path.
Returns {:path .. :count ..}.
Write `items` (seqable) under `header` (map) to `path`.
Returns {:path .. :count ..}.cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |